@@ -217,6 +217,24 @@ class FieldSet(object):
             if type(value) is Field:
                 assert value.name == attr, 'Field %s.name (%s) is not consistent' % (value.name, attr)
 
+        def check_velocityfields(U, V):
+            if (U.interp_method == 'cgrid_velocity' and V.interp_method != 'cgrid_velocity') or \
+                    (U.interp_method != 'cgrid_velocity' and V.interp_method == 'cgrid_velocity'):
+                raise ValueError("If one of U,V.interp_method='cgrid_velocity', the other should be too")
+
+            if 'linear_invdist_land_tracer' in [U.interp_method, V.interp_method]:
+                raise NotImplementedError("interp_method='linear_invdist_land_tracer' is not implemented for U and V Fields")
+
+            if U.interp_method == 'cgrid_velocity':
+                if U.grid.xdim == 1 or U.grid.ydim == 1 or V.grid.xdim == 1 or V.grid.ydim == 1:
+                    raise NotImplementedError('C-grid velocities require longitude and latitude dimensions at least length 2')
+
+        if isinstance(self.U, (SummedField, NestedField)):
+            for U, V in zip(self.U, self.V):
+                check_velocityfields(U, V)
+        else:
+            check_velocityfields(self.U, self.V)
+
         for g in self.gridset.grids:
             g.check_zonal_periodic()
             if len(g.time) == 1:
@@ -318,6 +336,8 @@ class FieldSet(object):
                fully load them (default: True). It is advised to deferred load the data, since in
                that case Parcels deals with a better memory management during particle set execution.
                deferred_load=False is however sometimes necessary for plotting the fields.
+        :param interp_method: Method for interpolation. Options are 'linear' (default), 'nearest',
+               'linear_invdist_land_tracer', 'cgrid_velocity', 'cgrid_tracer' and 'bgrid_velocity'
         :param field_chunksize: size of the chunks in dask loading
         :param netcdf_engine: engine to use for netcdf reading in xarray. Default is 'netcdf',
                but in cases where this doesn't work, setting netcdf_engine='scipy' could help
@@ -512,9 +532,11 @@ class FieldSet(object):
         """
 
         if 'U' in dimensions and 'V' in dimensions and dimensions['U'] != dimensions['V']:
-            raise RuntimeError("On a c-grid discretisation like NEMO, U and V should have the same dimensions")
+            raise ValueError("On a C-grid, the dimensions of velocities should be the corners (f-points) of the cells, so the same for U and V. "
+                             "See also https://nbviewer.jupyter.org/github/OceanParcels/parcels/blob/master/parcels/examples/documentation_indexing.ipynb")
         if 'U' in dimensions and 'W' in dimensions and dimensions['U'] != dimensions['W']:
-            raise RuntimeError("On a c-grid discretisation like NEMO, U, V and W should have the same dimensions")
+            raise ValueError("On a C-grid, the dimensions of velocities should be the corners (f-points) of the cells, so the same for U, V and W. "
+                             "See also https://nbviewer.jupyter.org/github/OceanParcels/parcels/blob/master/parcels/examples/documentation_indexing.ipynb")
 
         interp_method = {}
         for v in variables:
@@ -655,9 +677,11 @@ class FieldSet(object):
         """
 
         if 'U' in dimensions and 'V' in dimensions and dimensions['U'] != dimensions['V']:
-            raise RuntimeError("On a B-grid discretisation, U and V should have the same dimensions")
+            raise ValueError("On a B-grid, the dimensions of velocities should be the (top) corners of the grid cells, so the same for U and V. "
+                             "See also https://nbviewer.jupyter.org/github/OceanParcels/parcels/blob/master/parcels/examples/documentation_indexing.ipynb")
         if 'U' in dimensions and 'W' in dimensions and dimensions['U'] != dimensions['W']:
-            raise RuntimeError("On a B-grid discretisation, U, V and W should have the same dimensions")
+            raise ValueError("On a B-grid, the dimensions of velocities should be the (top) corners of the grid cells, so the same for U, V and W. "
+                             "See also https://nbviewer.jupyter.org/github/OceanParcels/parcels/blob/master/parcels/examples/documentation_indexing.ipynb")
 
         interp_method = {}
         for v in variables:
